@@ -110,8 +110,13 @@ class EngagementRateFB:
                 ) - timedelta(hours=5)
                 df_posts_full["date"] = df_posts_full["created_time"].dt.date
                 df_posts_full = pd.merge(
-                    df_posts_full, df_fan_count, on=["page_id", "date"], how="left"
+                    df_posts_full, df_fan_count, on=["page_id"], how="left"
                 )
+                df_posts_full = df_posts_full.rename(
+                    columns={"date_x":"date"}
+                )
+                df_posts_full = df_posts_full.drop(columns=["date_y"])
+                
                 df_posts_full["fan_count"] = df_posts_full.sort_values(
                     ["page_id", "date"]
                 )["fan_count"].fillna(method="bfill")
@@ -272,7 +277,7 @@ class EngagementRateIG:
                     ) - timedelta(hours=5)
                     df_posts_full["date"] = df_posts_full["date"].dt.date
                     df_posts_full = pd.merge(
-                        df_posts_full, df_fan_count, on=["owner_id", "date"], how="left"
+                        df_posts_full, df_fan_count, on=["owner_id"], how="left"
                     )
                     df_posts_full["followers"] = df_posts_full.sort_values(
                         ["owner_id", "date"]
