@@ -12,4 +12,4 @@ df_e['clean_text'] = df_e['message'].apply(lambda x: CleanText(x).process_text()
 
 pqrs = pqrs(df_p=df_e, batch=5).pqrs_df()
 
-print(pqrs[['_id', 'clean_text', 'is_pqrs']])
+print(pqrs[['clean_text', 'is_pqrs']])
